@@ -5,7 +5,7 @@ import typing as t
 from pydantic import BaseModel, Field, PrivateAttr
 
 if t.TYPE_CHECKING:
-    from pipelime.piper.progress.tracker.base import Tracker
+    from pipelime.piper.progress.tracker.base import Tracker, TrackedTask
 
 
 # The return type is a hack to fool the type checker
@@ -13,7 +13,9 @@ if t.TYPE_CHECKING:
 # TODO: forward with typing.ParamSpec (New in Python 3.10) to get full type checking
 @t.overload
 def command(
-    *, title: t.Optional[str] = None, **__config_kwargs,
+    *,
+    title: t.Optional[str] = None,
+    **__config_kwargs,
 ) -> t.Callable[[t.Callable[..., None]], t.Callable[..., t.Type["PipelimeCommand"]]]:
     ...
 
@@ -352,6 +354,7 @@ class PipelimeCommand(
         size: t.Optional[int] = None,
         message: str = "",
     ) -> t.Iterable:
+        """Track a sequence with a progress bar or a piper task."""
         import rich.progress
 
         if self._piper.active:
@@ -364,6 +367,10 @@ class PipelimeCommand(
                 description="🍋 " + message,
             )
 
+    def create_task(self, total: int, message: str = "") -> "TrackedTask":
+        """Explicit piper task creation."""
+        return self._get_piper_tracker().create_task(total, message)
+
     def __call__(self) -> None:
         self.run()
 
@@ -419,13 +426,20 @@ class NodesDefinition(BaseModel, extra="forbid", copy_on_model_validation="none"
             ],
         ],
     ):
-        from pipelime.cli.utils import get_pipelime_command
+        from pydantic import ValidationError
+        from pipelime.cli.utils import get_pipelime_command, show_field_alias_valerr
 
         if isinstance(value, NodesDefinition):
             return value
-        return cls(
-            __root__={name: get_pipelime_command(cmd) for name, cmd in value.items()}
-        )
+        try:
+            return cls(
+                __root__={
+                    name: get_pipelime_command(cmd) for name, cmd in value.items()
+                }
+            )
+        except ValidationError as e:
+            show_field_alias_valerr(e)
+            raise e
 
 
 class DAGModel(BaseModel, extra="forbid", copy_on_model_validation="none"):
